@@ -51,20 +51,22 @@ def select_image(runs):
         return 'ubuntu', 'ubuntu:12.04'
 
     # Debian
-    elif distribution != 'debian':
-        logging.warning("unsupported distribution %s, using Debian",
-                        distribution)
-        distribution, version = 'debian', '7'
-
-    if version == '6' or version.startswith('squeeze'):
-        return 'debian', 'debian:squeeze'
-    if version == '8' or version.startswith('jessie'):
-        return 'debian', 'debian:jessie'
     else:
-        if (version != '7' and not version.startswith('7.') and
-                not version.startswith('wheezy')):
-            logging.warning("using Debian 7 'Wheezy' instead of '%s'", version)
-        return 'debian', 'debian:wheezy'
+        if distribution != 'debian':
+            logging.warning("unsupported distribution %s, using Debian",
+                            distribution)
+            version = '7'
+
+        if version == '6' or version.startswith('squeeze'):
+            return 'debian', 'debian:squeeze'
+        elif version == '8' or version.startswith('jessie'):
+            return 'debian', 'debian:jessie'
+        else:
+            if (version != '7' and not version.startswith('7.') and
+                    not version.startswith('wheezy')):
+                logging.warning("using Debian 7 'Wheezy' instead of '%s'",
+                                version)
+            return 'debian', 'debian:wheezy'
 
 
 def write_dict(filename, dct):
@@ -77,7 +79,8 @@ def write_dict(filename, dct):
 def read_dict(filename):
     with filename.open('rb') as fp:
         dct = pickle.load(fp)
-    assert dct['unpacker'] == 'docker'
+    if dct['unpacker'] != 'docker':
+        raise ValueError("Wrong unpacker used: %s != docker" % dct['unpacker'])
     return dct
 
 
@@ -182,11 +185,16 @@ def docker_setup_build(args):
     image = make_unique_name(b'reprounzip_image_')
 
     logging.info("Calling 'docker build'...")
-    retcode = subprocess.call(['docker', 'build', '-t', image, '.'],
-                              cwd=target.path)
-    if retcode != 0:
-        logging.critical("docker build failed with code %d", retcode)
+    try:
+        retcode = subprocess.call(['docker', 'build', '-t', image, '.'],
+                                  cwd=target.path)
+    except OSError:
+        logging.critical("docker executable not found")
         sys.exit(1)
+    else:
+        if retcode != 0:
+            logging.critical("docker build failed with code %d", retcode)
+            sys.exit(1)
     logging.info("Initial image created: %s", image.decode('ascii'))
 
     unpacked_info['initial_image'] = image
@@ -438,7 +446,7 @@ def test_has_docker(pack, **kwargs):
     return COMPAT_MAYBE, "docker not found in PATH"
 
 
-def setup(parser):
+def setup(parser, **kwargs):
     """Runs the experiment in a Docker container
 
     You will need Docker to be installed on your machine if you want to run the
